﻿// 
// $Id: EventHandlers.cs 3982 2010-11-02 11:13:56Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxItem(false)]
    public class ZenEventHandlers<T> : IZenEventHandler<T> where T : class, new()
    {
        private T _onBlur;
        private T _onChange;
        private T _onClick;
        private T _onClose;
        private T _onDblClick;
        private T _onFocus;
        private T _onKeyDown;
        private T _onKeyPress;
        private T _onKeyUp;

        #region IZenEventHandler<T> Members

        [DojoEvent(Name = "onClick")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnClick
        {
            get { return _onClick ?? (_onClick = new T()); }
        }


        [DojoEvent(Name = "onBlur")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnBlur
        {
            get { return _onBlur ?? (_onBlur = new T()); }
        }

        [DojoEvent(Name = "onChange")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnChange
        {
            get { return _onChange ?? (_onChange = new T()); }
        }

        [DojoEvent(Name = "onClose")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnClose
        {
            get { return _onClose ?? (_onClose = new T()); }
        }


        [DojoEvent(Name = "onDblClick")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnDblClick
        {
            get { return _onDblClick ?? (_onDblClick = new T()); }
        }

        [DojoEvent(Name = "onFocus")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnFocus
        {
            get { return _onFocus ?? (_onFocus = new T()); }
        }

        [DojoEvent(Name = "onKeyDown")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnKeyDown
        {
            get { return _onKeyDown ?? (_onKeyDown = new T()); }
        }

        [DojoEvent(Name = "onKeyPress")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnKeyPress
        {
            get { return _onKeyPress ?? (_onKeyPress = new T()); }
        }

        [DojoEvent(Name = "onKeyUp")]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [NotifyParentProperty(true)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public virtual T OnKeyUp
        {
            get { return _onKeyUp ?? (_onKeyUp = new T()); }
        }

        #endregion

        //onMouseMove: "",
        //onMouseDown: "",
        //onMouseOut: "",
        //onMouseOver: "",
        //onMouseLeave: "",
        //onMouseEnter: "",
        //onMouseUp: "
    }
}