﻿// 
// $Id: Zen.cs 3982 2010-11-02 11:13:56Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.Text;
using System.Text.RegularExpressions;
using System.Web;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    public class Z
    {
        private static readonly Regex ClientExpansionRegex = new Regex(
            "\\x7B(.*?)\\x7D\r\n",
            RegexOptions.IgnoreCase | RegexOptions.CultureInvariant | RegexOptions.IgnorePatternWhitespace |
            RegexOptions.Compiled
            );

        private static readonly char[] ClientExpansionTrimSet = new[] {'#'};


        public static bool IsZenCallback
        {
            get { return HttpContext.Current.Request[CallbackHandler.ZEN_CALLBACK_MAGIC] != null; }
        }


        internal static string ExpandClientReference(Page page, string source)
        {
            string[] parts = ClientExpansionRegex.Split(source);
            var expanded = new StringBuilder();

            foreach (string s in parts)
            {
                if (s.Length > 0 && s[0] == '#')
                {
                    Control resolvedControl = FindControl(page, s.TrimStart(ClientExpansionTrimSet));
                    if (resolvedControl is WidgetBase)
                    {
                        expanded.Append(((WidgetBase) resolvedControl).DojoID);
                    }
                    else if (resolvedControl != null)
                    {
                        expanded.Append(resolvedControl.ClientID);
                    }
                }
                else
                {
                    expanded.Append(s);
                }
            }

            return expanded.ToString();
        }


        private static Control FindControl(Control haystack, Control ignoreControl, string needle)
        {
            if (haystack.ID == needle || haystack.UniqueID == needle)
            {
                return haystack;
            }

            // go deeper?
            if (haystack.HasControls())
            {
                foreach (Control testControl in haystack.Controls)
                {
                    if (testControl == ignoreControl) continue;
                    if (testControl.ID == needle || testControl.UniqueID == needle)
                    {
                        return testControl;
                    }

                    // go deeper?
                    if (testControl.HasControls())
                    {
                        Control testInternalControl = FindControl(testControl, null, needle);

                        if (testInternalControl != null)
                        {
                            return testInternalControl;
                        }
                    }
                }
            }

            return null;
        }

        public static Control FindControl(Control haystack, string needle)
        {
            // first try from the haystack down, if not then we search from the naming container out
            Control returnControl = FindControl(haystack, null, needle);

            // didn't find it here, so keep looking...
            if (returnControl == null)
            {
                Control searchTree = haystack.NamingContainer;
                Control ignoreControl = haystack;

                while (true)
                {
                    returnControl = FindControl(searchTree, ignoreControl, needle);

                    if (returnControl != null || searchTree.NamingContainer == null ||
                        searchTree.NamingContainer == searchTree)
                        break;

                    ignoreControl = searchTree;
                    searchTree = searchTree.NamingContainer;
                }
            }

            return returnControl;
        }
    }
}