﻿// 
// $Id: ProviderBase.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing.Design;
using System.Web.UI;
using System.Web.UI.Design;

#endregion

namespace Zen.Toolkit
{
    [ParseChildren(true)]
    [PersistChildren(false)]
    public abstract class ProviderBase : WidgetBase, IDataProvider
    {
        private DataStore _store;


        protected ProviderBase() : base(HtmlTextWriterTag.Div)
        {
        }

        protected ProviderBase(DataStore store) : base(HtmlTextWriterTag.Div)
        {
        }

        #region IDataProvider Members

        public DataStore Store { get; set; }

        [DojoProperty(Name = "url", SerializeAs = SerializationType.Url)]
        [UrlProperty]
        [Editor(typeof (UrlEditor), typeof (UITypeEditor))]
        [DefaultValue(null)]
        public string Url
        {
            get
            {
                object o = ViewState["Url"];
                return (o == null) ? null : (string) o;
            }

            set { ViewState["Url"] = value; }
        }

        [DojoProperty(Name = "data")]
        [Description(
            "This parameter can be used instead of url when you wish to load data differently then modify it to fit the expected format"
            )]
        public string Data
        {
            get
            {
                object o = ViewState["Data"];
                return (o == null) ? string.Empty : (string) o;
            }

            set { ViewState["Data"] = value; }
        }


        [DojoProperty(Name = "urlPreventCache")]
        [Description(
            "This boolean value controls whether dojo attempts to prevent the browser caching mechanism from caching values loaded from a webserver"
            )]
        [DefaultValue(true)]
        public bool PreventCaching
        {
            get
            {
                object o = ViewState["PreventCaching"];
                return (o == null) ? true : (bool) o;
            }

            set { ViewState["PreventCaching"] = value; }
        }

        [DojoProperty(Name = "clearOnClose")]
        [Description("If set, calling close() will erase all items stored in the internal structures")]
        [DefaultValue(true)]
        public bool ClearOnClose
        {
            get
            {
                object o = ViewState["ClearOnClose"];
                return (o == null) ? true : (bool) o;
            }

            set { ViewState["ClearOnClose"] = value; }
        }

        #endregion
    }
}