﻿// 
// $Id: Dialog.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System;
using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:Dialog runat=\"server\" Title=\"Dialog\"></{0}:Dialog>")]
    [ParseChildren(false)]
    [PersistChildren(true)]
    [DojoWidget(ClassMapping = "dijit.Dialog", InvokeStartup = false)]
    [DojoRequires(ModuleName = "dijit.Dialog")]
    [ToolboxBitmap(typeof (Dialog), "Resources.Icons.Toolbox.application.bmp")]
    public class Dialog : ContainerWidget
    {
        [DojoProperty(Name = "autofocus")]
        [Description(
            "A Toggle to modify the default focus behavior of a Dialog, which is to focus on the first dialog element after opening the dialog. False will disable autofocusing."
            )]
        [DefaultValue(true)]
        public bool AutoFocus
        {
            get
            {
                object o = ViewState["AutoFocus"];
                return (o == null) ? true : (bool) o;
            }

            set { ViewState["AutoFocus"] = value; }
        }

        [DefaultValue(true)]
        public bool AutoShow
        {
            get
            {
                object o = ViewState["AutoShow"];
                return (o == null) ? true : (bool) o;
            }

            set { ViewState["AutoShow"] = value; }
        }

        [DojoProperty(Name = "closeable")]
        [DefaultValue(false)]
        public bool Closable
        {
            get
            {
                object o = ViewState["Closable"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["Closable"] = value; }
        }


        [DojoProperty(Name = "draggable")]
        [DefaultValue(true)]
        public bool Draggable
        {
            get
            {
                object o = ViewState["Draggable"];
                return (o == null) ? true : (bool) o;
            }

            set { ViewState["Draggable"] = value; }
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
        }

        public override void OnBeforeGenerateScript()
        {
            if (AutoShow)
            {
                ZenManager.Script.AddAfterWidgetInit(this, "_show",
                                                     "{0}.show();", DojoID);
            }
        }
    }
}