﻿// 
// $Id: Button.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:Button runat=\"server\"></{0}:Button>")]
    [ToolboxBitmap(typeof (System.Web.UI.WebControls.Button))]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.form.Button", InvokeStartup = true)]
    [DojoRequires(ModuleName = "dijit.form.Button")]
    public class Button : FormWidget
    {
        private ZenEventHandlers<ZenClientEvent> _clientHandlers;
        private ZenEventHandlers<ZenServerEvent> _serverHandlers;

        public Button() : base(HtmlTextWriterTag.Button)
        {
        }

        public Enums.ButtonAction Action
        {
            get
            {
                object o = ViewState["Action"];
                return (o == null) ? Enums.ButtonAction.Normal : (Enums.ButtonAction) o;
            }

            set { ViewState["Action"] = value; }
        }

        [DojoServerEvents]
        [Category("Events")]
        [Themeable(false)]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Event Handlers")]
        public ZenEventHandlers<ZenServerEvent> ServerEvents
        {
            get
            {
                if (_serverHandlers == null)
                {
                    _serverHandlers = new ZenEventHandlers<ZenServerEvent>();
                }
                return _serverHandlers;
            }
        }

        [DojoClientEvents]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Clientside Event Handlers")]
        public ZenEventHandlers<ZenClientEvent> ClientEvents
        {
            get
            {
                if (_clientHandlers == null)
                {
                    _clientHandlers = new ZenEventHandlers<ZenClientEvent>();
                }
                return _clientHandlers;
            }
        }

        public override void OnBeforeGenerateScript()
        {
            switch (Action)
            {
                case Enums.ButtonAction.Normal:
                    AddConfig("type", "\"button\"");
                    break;
                case Enums.ButtonAction.Reset:
                    AddConfig("type", "\"reset\"");
                    break;
                case Enums.ButtonAction.Submit:
                    AddConfig("type", "\"submit\"");
                    break;
            }
        }

        protected override void RenderAttributes(HtmlTextWriter writer)
        {
            if (Visible)
            {
                //writer.AddAttribute(HtmlTextWriterAttribute.Type, "button");
                //writer.AddAttribute(HtmlTextWriterAttribute.Name, this.UniqueID);
            }

            base.RenderAttributes(writer);
        }
    }
}