﻿// 
// $Id: ComboBox.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;
using System.Web.UI.WebControls;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:ComboBox runat=\"server\"></{0}:ComboBox>")]
    [ToolboxBitmap(typeof (DropDownList))]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.form.ComboBox", InvokeStartup = false)]
    [DojoRequires(ModuleName = "dijit.form.ComboBox")]
    public class ComboBox : ValidationTextBox, IDataConsumer
    {
        [DojoProperty(Name = "store", SerializeAs = SerializationType.Raw, EmitNullOrEmpty = false)]
        private string StoreBinding
        {
            get { return (Store != null && Store.ProviderBinding != null) ? Store.ProviderBinding.DojoID : null; }
        }


        [DojoProperty(Name = "autoComplete")]
        [Description("")]
        [DefaultValue(false)]
        public bool AutoComplete
        {
            get
            {
                object o = ViewState["AutoComplete"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["AutoComplete"] = value; }
        }


        [DojoProperty(Name = "displayedValue")]
        public string DisplayValue
        {
            get { return (string) ViewState["DisplayValue"] ?? ""; }
            set { ViewState["DisplayValue"] = value; }
        }

        [DojoProperty(Name = "hasDownArrow")]
        [Description("")]
        [DefaultValue(true)]
        public bool ShowDownArrow
        {
            get
            {
                object o = ViewState["ShowDownArrow"];
                return (o == null) ? true : (bool) o;
            }
            set { ViewState["ShowDownArrow"] = value; }
        }

        [DojoProperty(Name = "ignoreCase")]
        [Description("")]
        [DefaultValue(true)]
        public bool IgnoreCase
        {
            get
            {
                object o = ViewState["IgnoreCase"];
                return (o == null) ? true : (bool) o;
            }
            set { ViewState["IgnoreCase"] = value; }
        }

        [DojoProperty(Name = "highlightMatch")]
        public Enums.HighlightMatch HighlightMatch
        {
            get
            {
                object o = ViewState["HighlightMatch"];
                return (o == null) ? Enums.HighlightMatch.None : (Enums.HighlightMatch) o;
            }

            set { ViewState["HighlightMatch"] = value; }
        }

        #region IDataConsumer Members

        [Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public DataStore Store
        {
            get
            {
                DataStore store = null;
                if (StoreId.Length != 0)
                {
                    store = Z.FindControl(this, StoreId) as DataStore;

                    if (store == null)
                    {
                        throw (new ZenControlNotFoundException(
                            "The associated store could not be found or is not a DataStore control"));
                    }
                }

                return store;
            }
        }

        [IDReferenceProperty(typeof (DataStore))]
        [DefaultValue("")]
        public string StoreId
        {
            get { return (string) ViewState["StoreID"] ?? ""; }
            set { ViewState["StoreID"] = value; }
        }

        #endregion
    }
}