﻿// 
// $Id: DropDownButton.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:DropDownButton runat=\"server\"></{0}:DropDownButton>")]
    [ToolboxBitmap(typeof (DropDownButton), "Resources.Icons.Toolbox.shape_ungroup.bmp")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.form.DropDownButton", InvokeStartup = false)]
    [DojoRequires(ModuleName = "dijit.form.DropDownButton")]
    public class DropDownButton : Button
    {
        private Menu _dropDownMenu;

        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Menu Menu
        {
            get
            {
                if (_dropDownMenu == null)
                {
                    _dropDownMenu = new Menu();
                }

                return _dropDownMenu;
            }
        }

        public override void OnBeforeGenerateScript()
        {
            EnsureChildControls();

            if (Menu != null)
            {
                ZenManager.Script.AddAfterWidgetInit(
                    this, "awi",
                    "{0}.dropDown = {1};",
                    DojoID,
                    Menu.DojoID);

                //this.AddConfig("dropDown", this.Menu.ClientID);
            }

            base.OnBeforeGenerateScript();
        }

        protected override void CreateChildControls()
        {
            if (Menu != null)
            {
                Menu.ID = ID + "_menu";
                Controls.Add(Menu);
            }

            base.CreateChildControls();
        }
    }
}