﻿// 
// $Id: ValidationTextBox.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:ValidationTextBox runat=\"server\"></{0}:ValidationTextBox>")]
    [ToolboxBitmap(typeof (ValidationTextBox), "Resources.Icons.Toolbox.textfield_delete.bmp")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.form.ValidationTextBox", InvokeStartup = false)]
    [DojoRequires(ModuleName = "dijit.form.ValidationTextBox")]
    public class ValidationTextBox : TextBox
    {
        [DojoProperty(Name = "invalidMessage")]
        public string InvalidMessage
        {
            get { return (string) ViewState["InvalidMessage"] ?? ""; }
            set { ViewState["InvalidMessage"] = value; }
        }

        [DojoProperty(Name = "missingMessage")]
        public string MissingMessage
        {
            get { return (string) ViewState["MissingMessage"] ?? ""; }
            set { ViewState["MissingMessage"] = value; }
        }

        [DojoProperty(Name = "promptMessage")]
        public string PromptMessage
        {
            get { return (string) ViewState["PromptMessage"] ?? ""; }
            set { ViewState["PromptMessage"] = value; }
        }

        [DojoProperty(Name = "regExp")]
        public string ValidationExpression
        {
            get { return (string) ViewState["ValidationExpression"] ?? ""; }
            set { ViewState["ValidationExpression"] = value; }
        }


        [DojoProperty(Name = "required")]
        [Description("User is required to enter data into this field.")]
        [DefaultValue(false)]
        public bool IsRequired
        {
            get
            {
                object o = ViewState["IsRequired"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["IsRequired"] = value; }
        }


        [Description("Whether the field validation should occur on page load.")]
        [DefaultValue(false)]
        public bool ValidateOnLoad
        {
            get
            {
                object o = ViewState["ValidateOnLoad"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["ValidateOnLoad"] = value; }
        }

        public override void OnBeforeGenerateScript()
        {
            if (ValidateOnLoad)
            {
                ZenManager.Script.AddLazyWidgetInit(
                    this, "vol",
                    string.Format("{0}.validate();",
                                  DojoID));
            }

            base.OnBeforeGenerateScript();
        }
    }
}