﻿// 
// $Id: _FormTextWidget.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ParseChildren(true, "value")]
    [PersistChildren(false)]
    public abstract class FormTextWidget : FormValueWidget
    {
        private ZenEventHandlers<ZenClientEvent> _clientHandlers;

        protected FormTextWidget(HtmlTextWriterTag tag) : base(tag)
        {
        }

        [DojoClientEvents]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Clientside Event Handlers")]
        public ZenEventHandlers<ZenClientEvent> ClientEvents
        {
            get
            {
                if (_clientHandlers == null)
                {
                    _clientHandlers = new ZenEventHandlers<ZenClientEvent>();
                }
                return _clientHandlers;
            }
        }

        [DojoProperty(Name = "readOnly")]
        [Description("")]
        [DefaultValue(false)]
        public bool ReadOnly
        {
            get
            {
                object o = ViewState["ReadOnly"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["ReadOnly"] = value; }
        }

        [Description("")]
        [DefaultValue(Enums.ConvertCase.None)]
        public Enums.ConvertCase CaseAdjust
        {
            get
            {
                object o = ViewState["CaseAdjust"];
                return (o == null) ? Enums.ConvertCase.None : (Enums.ConvertCase) o;
            }
            set { ViewState["CaseAdjust"] = value; }
        }

        [DojoProperty(Name = "maxLength")]
        [Description("")]
        [DefaultValue(null)]
        public int? MaxLength
        {
            get
            {
                object o = ViewState["MaxLength"];
                return (o == null) ? null : (int?) o;
            }
            set { ViewState["MaxLength"] = value; }
        }

        [DojoProperty(Name = "placeHolder")]
        public string PlaceHolder
        {
            get { return (string) ViewState["PlaceHolder"] ?? ""; }
            set { ViewState["PlaceHolder"] = value; }
        }

        [DojoProperty(Name = "selectOnClick")]
        [Description("If true, all text will be selected when focused with mouse")]
        [DefaultValue(false)]
        public bool SelectOnClick
        {
            get
            {
                object o = ViewState["SelectOnClick"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["SelectOnClick"] = value; }
        }


        [DojoProperty(Name = "trim")]
        [Description("Removes leading and trailing whitespace if true. Default is false.")]
        [DefaultValue(false)]
        public bool Trim
        {
            get
            {
                object o = ViewState["Trim"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["Trim"] = value; }
        }

        public override void OnBeforeGenerateScript()
        {
            switch (CaseAdjust)
            {
                case Enums.ConvertCase.Lowercase:
                    AddConfig("lowercase", "true");
                    break;

                case Enums.ConvertCase.Propercase:
                    base.AddConfig("propercase", "true");
                    break;

                case Enums.ConvertCase.Uppercase:
                    base.AddConfig("uppercase", "true");
                    break;
            }
        }
    }
}