﻿// 
// $Id: _FormValueWidget.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    public abstract class FormValueWidget : FormWidget, IPostBackDataHandler
    {
        private static readonly object EventValueChanged = new object();


        protected FormValueWidget(HtmlTextWriterTag tag)
            : base(tag)
        {
        }


        [DojoProperty(Name = "value")]
        [DefaultValue("")]
        [Bindable(true, BindingDirection.TwoWay)]
        [Description("Set the Value of this Hidden")]
        [PersistenceMode(PersistenceMode.EncodedInnerDefaultProperty)]
        public string Value
        {
            get { return (string) ViewState["Value"] ?? ""; }
            set { ViewState["Value"] = value; }
        }

        #region IPostBackDataHandler Members

        bool IPostBackDataHandler.LoadPostData(string postDataKey, NameValueCollection postCollection)
        {
            return LoadPostData(postDataKey, postCollection);
        }

        void IPostBackDataHandler.RaisePostDataChangedEvent()
        {
            RaisePostDataChangedEvent();
        }

        #endregion

        public override void OnBeforeGenerateScript()
        {
            AddConfig("name", "\"{0}\"", ClientID);
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            if (Page != null)
            {
                Page.RegisterRequiresPostBack(this);
            }
        }

        public event EventHandler ValueChanged
        {
            add { base.Events.AddHandler(EventValueChanged, value); }
            remove { base.Events.RemoveHandler(EventValueChanged, value); }
        }

        protected virtual bool LoadPostData(string postDataKey, NameValueCollection postCollection)
        {
            string val = postCollection[string.Concat(ClientID)];
            if (!string.IsNullOrEmpty(val))
            {
                Value = val;
                return true;
            }
            return false;
        }

        protected virtual void RaisePostDataChangedEvent()
        {
        }
    }
}