﻿// 
// $Id: BorderLayout.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;
using System.Web.UI.WebControls;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:BorderLayout runat=\"server\"></{0}:BorderLayout>")]
    [ToolboxBitmap(typeof (BorderLayout), "Resources.Icons.Toolbox.application_side_boxes.bmp")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.layout.BorderContainer", InvokeStartup = true)]
    [DojoRequires(ModuleName = "dijit.layout.BorderContainer")]
    public class BorderLayout : WidgetBase
    {
        private Panel _regionBottom;
        private Panel _regionCenter;
        private Panel _regionLeft;
        private Panel _regionRight;
        private Panel _regionTop;

        public BorderLayout()
            : base(HtmlTextWriterTag.Div)
        {
        }


        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Panel Top
        {
            get { return _regionTop ?? (_regionTop = new Panel(this, Enums.LayoutRegion.Top)); }
        }


        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Panel Bottom
        {
            get { return _regionBottom ?? (_regionBottom = new Panel(this, Enums.LayoutRegion.Bottom)); }
        }

        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Panel Left
        {
            get { return _regionLeft ?? (_regionLeft = new Panel(this, Enums.LayoutRegion.Left)); }
        }

        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Panel Right
        {
            get { return _regionRight ?? (_regionRight = new Panel(this, Enums.LayoutRegion.Right)); }
        }

        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Panel Center
        {
            get { return _regionCenter ?? (_regionCenter = new Panel(this, Enums.LayoutRegion.Center)); }
        }


        [DojoStyle(Name = "width")]
        public Unit Width
        {
            get
            {
                object o = ViewState["Width"];
                return (o == null) ? Unit.Empty : (Unit) o;
            }

            set { ViewState["Width"] = value; }
        }

        [DojoStyle(Name = "height")]
        public Unit Height
        {
            get
            {
                object o = ViewState["Height"];
                return (o == null) ? Unit.Empty : (Unit) o;
            }

            set { ViewState["Height"] = value; }
        }

        [DojoProperty(Name = "gutters")]
        [DefaultValue(false)]
        public bool Gutters
        {
            get
            {
                object o = ViewState["Gutters"];
                return (o == null) ? false : (bool) o;
            }

            set { ViewState["Gutters"] = value; }
        }

        [DojoProperty(Name = "liveSplitters")]
        [DefaultValue(false)]
        public bool LiveSplitter
        {
            get
            {
                object o = ViewState["LiveSplitter"];
                return (o == null) ? false : (bool) o;
            }

            set { ViewState["LiveSplitter"] = value; }
        }

        [DojoProperty(Name = "persist")]
        [Description("Save splitter positions in a cookie.")]
        [DefaultValue(false)]
        public bool Persist
        {
            get
            {
                object o = ViewState["Persist"];
                return (o == null) ? false : (bool) o;
            }

            set { ViewState["Persist"] = value; }
        }

        [DojoProperty(Name = "design", SerializeAs = SerializationType.Raw)]
        public Enums.LayoutDesign Design
        {
            get
            {
                object o = ViewState["Design"];
                return (o == null) ? Enums.LayoutDesign.Headline : (Enums.LayoutDesign) o;
            }

            set { ViewState["Design"] = value; }
        }

        protected override void CreateChildControls()
        {
            foreach (Panel pane in new[]
                                       {
                                           _regionTop, _regionLeft, _regionRight, _regionBottom, _regionCenter
                                       })
            {
                if (pane != null)
                {
                    Controls.Add(pane);
                }
            }

            base.CreateChildControls();
        }
    }
}