﻿// 
// $Id: ContainerWidget.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing.Design;
using System.Web.UI;
using System.Web.UI.Design;
using System.Web.UI.WebControls;

#endregion

namespace Zen.Toolkit
{
    [ParseChildren(false)]
    [PersistChildren(true)]
    public abstract class ContainerWidget : WidgetBase
    {
        protected ContainerWidget(HtmlTextWriterTag tag) : base(tag)
        {
        }

        protected ContainerWidget() : base(HtmlTextWriterTag.Div)
        {
        }

        [DojoProperty(Name = "doLayout")]
        [DefaultValue(false)]
        public bool AutoSizeChildren
        {
            get
            {
                object o = ViewState["AutoSizeChildren"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["AutoSizeChildren"] = value; }
        }

        [DojoProperty(Name = "extractContent")]
        [Description(
            "Extract visible content from inside of <body> .... </body>. I.e., strip <html> and <head> (and it's contents) from the href"
            )]
        [DefaultValue(false)]
        public bool ExtractContent
        {
            get
            {
                object o = ViewState["ExtractContent"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["ExtractContent"] = value; }
        }

        [DojoProperty(Name = "preventCache")]
        [Description("Prevent caching of data from href's by appending a timestamp to the href.")]
        [DefaultValue(false)]
        public bool PreventCaching
        {
            get
            {
                object o = ViewState["PreventCaching"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["PreventCaching"] = value; }
        }

        [DojoProperty(Name = "refreshOnShow")]
        [Description("Refresh (re-download) content when pane goes from hidden to shown")]
        [DefaultValue(false)]
        public bool RefreshOnShow
        {
            get
            {
                object o = ViewState["RefreshOnShow"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["RefreshOnShow"] = value; }
        }


        [DojoProperty(Name = "loadingMessage")]
        [Description("Message that shows while downloading")]
        [DefaultValue("")]
        public string LoadingMessage
        {
            get { return (string) ViewState["LoadingMessage"] ?? ""; }
            set { ViewState["LoadingMessage"] = value; }
        }

        [DojoProperty(Name = "hasShadow")]
        [DefaultValue(false)]
        public bool ShowShadow
        {
            get
            {
                object o = ViewState["ShowShadow"];
                return (o == null) ? false : (bool) o;
            }

            set { ViewState["ShowShadow"] = value; }
        }

        [DojoProperty(Name = "href", SerializeAs = SerializationType.Url)]
        [UrlProperty]
        [EditorAttribute(typeof (UrlEditor), typeof (UITypeEditor))]
        [DefaultValue(null)]
        public string ContentUrl
        {
            get
            {
                object o = ViewState["ContentUrl"];
                return (o == null) ? null : (string) o;
            }

            set { ViewState["ContentUrl"] = value; }
        }

        [DojoProperty(Name = "region")]
        [DefaultValue(Enums.LayoutRegion.None)]
        public Enums.LayoutRegion Region
        {
            get
            {
                object o = ViewState["Region"];
                return (o == null) ? Enums.LayoutRegion.None : (Enums.LayoutRegion) o;
            }

            set { ViewState["Region"] = value; }
        }

        [DojoProperty(Name = "splitter")]
        [DefaultValue(false)]
        public bool Splitter
        {
            get
            {
                object o = ViewState["Splitter"];
                return (o == null) ? false : (bool) o;
            }

            set { ViewState["Splitter"] = value; }
        }

        [DojoStyle(Name = "width")]
        public Unit Width
        {
            get
            {
                object o = ViewState["Width"];
                return (o == null) ? Unit.Empty : (Unit) o;
            }

            set { ViewState["Width"] = value; }
        }

        [DojoStyle(Name = "height")]
        public Unit Height
        {
            get
            {
                object o = ViewState["Height"];
                return (o == null) ? Unit.Empty : (Unit) o;
            }

            set { ViewState["Height"] = value; }
        }
    }
}