﻿// 
// $Id: MenuItem.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System;
using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:MenuItem runat=\"server\"></{0}:MenuItem>")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.MenuItem", InvokeStartup = false, RenderPlaceHolder = true)]
    [DojoRequires(ModuleName = "dijit.MenuItem")]
    [ToolboxBitmap(typeof (MenuItem), "Resources.Icons.Toolbox.application_view_tile.bmp")]
    public class MenuItem : WidgetBase
    {
        private ZenEventHandlers<ZenClientEvent> _clientHandlers;
        private ZenEventHandlers<ZenServerEvent> _serverHandlers;
        private Menu _subMenu;

        public MenuItem() : base(HtmlTextWriterTag.Div)
        {
        }

        internal WidgetBase Container { get; set; }

        [DojoProperty(Name = "iconClass")]
        public string IconClass
        {
            get { return (string) ViewState["IconClass"] ?? ""; }
            set { ViewState["IconClass"] = value; }
        }


        [DojoProperty(Name = "accelKey")]
        public string AcceleratorKey
        {
            get { return (string) ViewState["AcceleratorKey"] ?? ""; }
            set { ViewState["AcceleratorKey"] = value; }
        }

        [DojoProperty(Name = "disabled")]
        [DefaultValue(false)]
        public bool Disabled
        {
            get
            {
                object o = ViewState["Disabled"];
                return (o == null) ? false : (bool) o;
            }
            set { ViewState["Disabled"] = value; }
        }

        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TypeConverter(typeof (ExpandableObjectConverter))]
        public Menu Menu
        {
            get { return _subMenu ?? (_subMenu = new Menu()); }
        }

        [DojoServerEvents]
        [Category("Events")]
        [Themeable(false)]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Event Handlers")]
        public ZenEventHandlers<ZenServerEvent> ServerEvents
        {
            get { return _serverHandlers ?? (_serverHandlers = new ZenEventHandlers<ZenServerEvent>()); }
        }

        [DojoClientEvents]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Clientside Event Handlers")]
        public ZenEventHandlers<ZenClientEvent> ClientEvents
        {
            get { return _clientHandlers ?? (_clientHandlers = new ZenEventHandlers<ZenClientEvent>()); }
        }

        protected override void CreateChildControls()
        {
            if (_subMenu != null)
                Controls.Add(_subMenu);

            base.CreateChildControls();
        }

        protected override void OnPreRender(EventArgs e)
        {
            if (Container != null)
            {
                ZenManager.Script.AddAfterWidgetInit(
                    this, "awi",
                    "{0}.addChild({1});",
                    Container.DojoID,
                    DojoID);
            }

            if (_subMenu != null)
            {
                ZenManager.Script.AddAfterWidgetInit(
                    this, "awi_popup",
                    "{0}.popup = {1};",
                    DojoID,
                    Menu.DojoID);
            }
            base.OnPreRender(e);
        }
    }
}