﻿// 
// $Id: MenuPopupItem.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Drawing.Design;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:MenuPopupItem runat=\"server\"></{0}:MenuPopupItem>")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.PopupMenuItem", InvokeStartup = false, RenderPlaceHolder = true)]
    [DojoRequires(ModuleName = "dijit.PopupMenuItem")]
    [ToolboxBitmap(typeof (MenuPopupItem), "Resources.Icons.Toolbox.application_view_tile.bmp")]
    public class MenuPopupItem : MenuItem
    {
        private List<WidgetBase> _popupList;


        [NotifyParentProperty(true)]
        [DefaultValue(null)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [Editor(typeof (PopupItemCollectionEditor), typeof (UITypeEditor))]
        public virtual List<WidgetBase> Popup
        {
            get
            {
                if (_popupList == null)
                    _popupList = new List<WidgetBase>();

                return _popupList;
            }
        }

        protected override void CreateChildControls()
        {
            if (_popupList != null)
            {
                if (_popupList.Count > 1)
                {
                    throw new ZenWidgetException(
                        "There are too many controls in the popup declaration.  Currently only one control can be used for the popup");
                }


                foreach (WidgetBase popper in _popupList)
                {
                    if (popper is IPopper)
                    {
                        Controls.Add(popper);
                        ZenManager.Script.AddAfterWidgetInit(
                            this, "pop",
                            "{0}.popup = {1};",
                            DojoID,
                            popper.DojoID);
                    }
                    else
                    {
                        throw new ZenWidgetException("The control {0} cannot be used as a popup item", popper.ID);
                    }
                }
            }
            base.CreateChildControls();
        }

        #region Nested type: PopupItemCollectionEditor

        public class PopupItemCollectionEditor : CollectionEditor
        {
            public PopupItemCollectionEditor(Type type)
                : base(type)
            {
            }

            protected override bool CanSelectMultipleInstances()
            {
                return false;
            }

            protected override Type CreateCollectionItemType()
            {
                return typeof (IPopper);
            }

            protected override Type[] CreateNewItemTypes()
            {
                return new[]
                           {
                               typeof (IPopper)
                           };
            }
        }

        #endregion
    }
}