﻿// 
// $Id: Tabstrip.cs 3981 2010-11-02 11:12:16Z unknown $
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Drawing.Design;
using System.Web.UI;
using System.Web.UI.WebControls;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:Tabstrip runat=\"server\"></{0}:Tabstrip>")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.layout.TabContainer", InvokeStartup = true)]
    [DojoRequires(ModuleName = "dijit.layout.TabContainer")]
    [DojoRequires(ModuleName = "dijit.layout.ContentPane")]
    [ToolboxBitmap(typeof(Tabstrip), "Resources.Icons.Toolbox.application_view_tile.bmp")]
    public class Tabstrip : WidgetBase
    {
        private readonly List<Panel> _panelList = new List<Panel>();

        public Tabstrip()
            : base(HtmlTextWriterTag.Div)
        {
        }

        [Category("Config Options")]
        [NotifyParentProperty(true)]
        [DefaultValue(null)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [Editor(typeof(PanelCollectionEditor), typeof(UITypeEditor))]
        [Description("A collection of panels.")]
        public virtual List<Panel> Panels
        {
            get
            {
                return _panelList;
            }
        }

        protected override void OnPreRender(EventArgs e)
        {
            AddStyle("width", Unit.Percentage(100).ToString());
            AddStyle("height", Unit.Percentage(100).ToString());
            base.OnPreRender(e);
        }

        protected override void CreateChildControls()
        {
            foreach (Panel panel in _panelList)
            {
                //panel.Container = this;
                Controls.Add(panel);
            }

            base.CreateChildControls();
        }

        #region Nested type: PanelCollectionEditor

        public class PanelCollectionEditor : CollectionEditor
        {
            public PanelCollectionEditor(Type type)
                : base(type)
            {
            }

            protected override bool CanSelectMultipleInstances()
            {
                return false;
            }

            protected override Type CreateCollectionItemType()
            {
                return typeof(Panel);
            }

            protected override Type[] CreateNewItemTypes()
            {
                return new[]
                           {
                               typeof (Tabstrip)
                           };
            }
        }

        #endregion
    }
}