﻿// 
// $Id$
// 
// Zen UI Toolkit Copyright (c) 2010, Paul Clancy.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification, are permitted provided 
// that the following conditions are met:
// 
// * 	Redistributions of source code must retain the above copyright notice, this list of 
// 	conditions and the following disclaimer.
// 
// * 	Redistributions in binary form must reproduce the above copyright notice, this list of 
// 	conditions and the following disclaimer in the documentation and/or other materials 
// 	provided with the distribution.
// 
// * 	Neither the name of AppTek nor the names of its contributors may be used to endorse 
// 	or promote products derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
// THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 

#region

using System.ComponentModel;
using System.Drawing;
using System.Web.UI;

#endregion

namespace Zen.Toolkit
{
    [ToolboxData("<{0}:Tree runat=\"server\"></{0}:Tree>")]
    [ParseChildren(true)]
    [PersistChildren(false)]
    [DojoWidget(ClassMapping = "dijit.Tree", InvokeStartup = true)]
    [DojoRequires(ModuleName = "dijit.Tree")]
    [ToolboxBitmap(typeof (Tree), "Resources.Icons.Toolbox.application_view_tile.bmp")]
    public class Tree : WidgetBase
    {
        private ZenEventHandlers<ZenClientEvent> _clientHandlers;
        private ZenEventHandlers<ZenServerEvent> _serverHandlers; 
        private readonly ForestStoreModel _model = new ForestStoreModel();

        public Tree()
            : base(HtmlTextWriterTag.Div)
        {
        }


        public Tree(HtmlTextWriterTag tag)
            : base(tag)
        {
        }


        [NotifyParentProperty(true)]
        [DefaultValue(null)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        public virtual ForestStoreModel Model
        {
            get { return _model; }
        }


        [DojoServerEvents]
        [Category("Events")]
        [Themeable(false)]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Event Handlers")]
        public ZenEventHandlers<ZenServerEvent> ServerEvents
        {
            get { return _serverHandlers ?? (_serverHandlers = new ZenEventHandlers<ZenServerEvent>()); }
        }

        [DojoClientEvents]
        [NotifyParentProperty(true)]
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)]
        [Description("Client side Event Handlers")]
        public ZenEventHandlers<ZenClientEvent> ClientEvents
        {
            get { return _clientHandlers ?? (_clientHandlers = new ZenEventHandlers<ZenClientEvent>()); }
        }


        protected override void CreateChildControls()
        {
            Controls.Add(_model);
            base.CreateChildControls();
        }

        public override void OnBeforeGenerateScript()
        {
            Push();
            AddConfig("model", _model.DojoID);
        }
    }
}